
#include "memory_Context.h"

#ifndef main_HEADER
#define main_HEADER

memory_Context memory_detectMismatchedItems(memory_Context);
memory_Context memory_detectVictory(memory_Context);
memory_Context memory_generateConstPlayfield(memory_Context);
memory_Context memory_hideMatchingItems(memory_Context);
memory_Context memory_selectItem(memory_Context);
std::string memory_test_detectMismatchedItems();
std::string memory_test_detectMismatchedItems_itemTwice();
std::string memory_test_detectVictory();
std::string memory_test_generateConstPlayfield();
std::string memory_test_hideMatchingItems();
std::string memory_test_selectItem_1x();
std::string memory_test_selectItem_2x();
std::string memory_test_selectItem_3x();
memory_Context cli_exit(memory_Context);
memory_Context cli_goOn(memory_Context);
memory_Context cli_greetUser(memory_Context);
memory_Context cli_promptSecondItemSelection(memory_Context);
memory_Context cli_reportMatchedItems(memory_Context);
memory_Context cli_reportVictory(memory_Context);
memory_Context cli_selectItem(memory_Context);
memory_Context cli_showHelp(memory_Context);
memory_Context cli_reportMismatchedItems(memory_Context);
std::string cli_test_exit_e();
std::string cli_test_exit_exit();
std::string cli_test_exit_victory();
std::string cli_test_exit_q();
std::string cli_test_exit_quit();
std::string cli_test_goOn();
std::string cli_test_greetUser();
std::string cli_test_promptSecondItemSelection();
std::string cli_test_reportMatchedItems();
std::string cli_test_reportMismatchedItems();
std::string cli_test_selectItem();
std::string cli_test_showHelp_h();
std::string cli_test_showHelp_help();
std::string cli_test_reportVictory();
std::string ctx_test_Controller_executeFunctions_set();
std::string ctx_test_Controller_processQueue();
std::string ctx_test_memoryContext_field();
std::string ctx_test_memoryContext_setField();
std::string llm_test_isDigit_digit();
std::string llm_test_isDigit_notDigit();
std::string llm_test_strToInt();

#endif // main_HEADER

